## Alice Blue API Sample Codes and Unofficial Functions
Samples of AliceBlue Ant API Sample Codes for Live Algo Trading using [Krishna's Python Wrapper](https://github.com/krishnavelu/alice_blue/issues). 

[Unofficed](https://www.unofficed.com/) is strategic partner of Alice Blue

 [Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_1_Connecting_to_Websocket_and_Getting_Live_LTP_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1vJmIXGTPe8Ckkx_psmO2Z5h4FXbp1Z4H?usp=sharing) Program 1: Connecting to Websocket and Getting Live LTP


[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_2_Making_a_function_to_get_all_Instruments_List_a_Pandas_DataFrame_By_Unofficed.ipynb
) |
[Google Collab](https://colab.research.google.com/drive/1_FU6en-VbXT3fOnRcmkrQ6VMG3JOPts2#scrollTo=h2yP-37ZFq2f) Program 2: Making a function to get all  Instruments List a Pandas DataFrame

[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_3_Historical_Data_Download_Python_Code_for_any_stock_of_Stock_Market_Using_Ant_API_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1JBvwujwv_OlYGjCEt3o-C88VwfdOMvKr?usp=sharing) Program 3: Historical Data Download Python Code for any stock of Stock Market

### Indicators

#### Bollinger Band

[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_4_Plotting_Bollinger_band_On_Historical_data_of_Infosys_Using_Python_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1h5jLJnwkWo0ZizXnL_D6bXrlxw0gvpp1?usp=sharing) Program 4: Plotting Bollinger band On Historical data of Infosys Using Python 

#### Simple Moving Average

[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_5_Coding_and_Plotting_Simple_Moving_Average_Indicator_of_Infosys_Using_Python_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1lSM_BJJc8Kk85LxXtJtmSqKhotvY2HWz?usp=sharing) Program 5: Coding and Plotting Simple Moving Average Indicator of Infosys Using Python

#### Exponential Moving Average

[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_6_Coding_and_Plotting_Exponential_Moving_Average_Indicator_of_Infosys_Using_Python_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1JWmgABXvBK6dWWhpUcEQconw9DI2LV4e?usp=sharing) Program 6: Coding and Plotting Exponential Moving Average Indicator of Infosys Using Python

#### SMA/EMA Crossover

[Github](https://github.com/aeron7/alice_blue_pro/blob/main/AliceBlue_Sample_Program_7_How_to_plot_Moving_Average_Crossover_Using_Python_in_Indian_Stock_Market_By_Unofficed.ipynb) |
[Google Collab](https://colab.research.google.com/drive/1mrEmMYkJ_eQgXIpu7xQkdymBB_TR7qsJ?usp=sharing) Program 7: How to plot Moving Average Crossover Using Python in Indian Stock Market 

## AlgoTrading Using Python and Alice Blue API - Complete Series
[Article 1: How to activate the API in Alice Blue for Automated Trading](https://unofficed.com/how-to-activate-the-api-in-alice-blue-for-automated-trading/)

[Article 2: How to Stream Live Trading data using Python and AliceBlue ANT API](https://unofficed.com/alice-blue/aliceblue-live-data/)

## Contributing
For Discussion and Improving this Code, Join - https://www.unofficed.com/chat/

## License
[MIT](https://choosealicense.com/licenses/mit/)
